PowANOVA: A function to obtain a power table with the combination of
various number of PDX lines and number of individuals per PDX lines per treatment based on a prior knowledge of median survival
Description
A function to obtain a power table with the combination of
various number of PDX lines and number of individuals per PDX lines per treatment based on a prior knowledge of median survival
the estimates of statistical power across n and m.
Arguments
ctl.med.surv
a numeric value of the hypothesized medial survival in the control arm. Default is 2.4.
tx.med.surv
a numeric value of the hypothesized medial survival in the treatment arm. Default is 4.8.
tau2
variance of PDX line specific random effect. Default is NULL. tau2 should be specified only when icc is set as NULL.
icc
intraclass correlation coefficient. Default is 0.1. If icc is specified,
then tau2 will be calculated automatically. Otherwise, tau2 must be specified.
sigma2
variance of random error.
n
an integer number to specify the number of PDX lines.
m
an integer number to specify the number of individuals per PDX line per treatment.
sim
Number of Monte Carlo samples to be generated. Default is 100.
two.sided
A logical value to indicate if a two-sided hypothesis testing is conducted. Default is TRUE.